class MembersController < ApplicationController
  before_filter :authenticate_member!
  load_and_authorize_resource

  def index
    @members = Member.accessible_by(current_ability)
  end

  def show
    @member = Member.find(params[:id])
    unless @member.last_subscription_paid?
      @new_subscription = @member.subscriptions.build(:paid_on => Time.now)
    end
  end

  def new
    @member = Member.new
  end

  def create
    @member = Member.new(params[:member])
    @member.password = Devise.friendly_token
    @member.joined_on = Time.now
    respond_to do |format|
      if @member.save
        MemberMailer.welcome_email(@member, "#{request.protocol}#{request.host}").deliver
        format.html  { redirect_to @member,
                                   :notice => I18n.t(:new_member_added) }
        format.json  { render :json => @member,
                              :status => :created, :location => @member }
      else
        format.html  { render :action => "new" }
        format.json  { render :json => @member.errors,
                              :status => :unprocessable_entity }
      end
    end
  end

  def edit
    @member = Member.find(params[:id])
  end

  def update
    @member = Member.find(params[:id])

    respond_to do |format|
      if @member.update_attributes(params[:member])
        format.html { redirect_to @member, notice: I18n.t(:member_updated) }
        format.json { head :no_content }
      else
        format.html { render action: "edit" }
        format.json { render json: @member.errors, status: :unprocessable_entity }
      end
    end
  end

  # For emails address of actives members (see #388)
  def list
    @members = Member.accessible_by(current_ability)
    render file: "members/list.text.erb"
  end

end
