class Member < ActiveRecord::Base
  devise :database_authenticatable, :recoverable,
         :rememberable, :trackable, :validatable

  validates_presence_of :name, :message => I18n.t(:name_missing)
  validates_presence_of :address, :message => I18n.t(:address_missing)

  # Add better error message to email presence validator than is configured by Devise
  def email_required?; false; end
  validates_presence_of :email, :message => I18n.t(:email_missing)

  attr_accessible :name, :email, :address, :password, :password_confirmation, :remember_me

  has_many :subscriptions, :order => 'paid_on ASC'
  has_many :vpn_services

  def last_subscription_paid?
		if last_subscription != nil
			advanced = last_subscription.paid_on.to_time.advance(:years => 1)
			advanced > Time.now
		else
			false
		end
  end

  def last_subscription
    subscriptions.all.last
  end
end
