# -*- coding: utf-8 -*-

Given /^(?:que )?l'association compte Fabien comme membre/ do
  @fabien = FactoryGirl.create(:fabien)
end

Given /^que Fabien a payé sa cotisation pour l'année en cours$/ do
  year = Time.now.year
  @fabien.subscriptions.create(:paid_on => Time.utc(year), :amount => '1500')
end

Given /^que Fabien a payé sa dernière cotisation (\d+) jours avant$/ do |days|
  timestamp = Time.now.to_i - 24*3600 * days.to_i
  @fabien.subscriptions.create(:paid_on => Time.at(timestamp), :amount => '1500')
end

Given /^que ce membre a payé sa dernière cotisation (\d+) jours avant$/ do |days|
  timestamp = Time.now.to_i - 24*3600 * days.to_i
  @member.subscriptions.create(:paid_on => Time.at(timestamp), :amount => '1500')
end

Given /^un membre à jour de cotisation$/ do
  @member = FactoryGirl.create(:member)
end

Given /^un membre dont la dernière cotisation date de plus d'un an$/ do
  @member = FactoryGirl.create(:member, :joined_on => Time.utc(2010),
                                        :subscriptions_paid => false)
  @member.subscriptions.create(:paid_on => Time.utc(2010), :amount => '1500')
end

Given /^(?:que )?Fabien dont la dernière cotisation date de plus d'un an est membre de l'association$/ do
  @fabien = FactoryGirl.create(:fabien, :joined_on => Time.utc(2010),
                                        :subscriptions_paid => false)
  @fabien.subscriptions.create(:paid_on => Time.utc(2010), :amount => '1500')
end

When /^j'enregistre un membre avec son nom, son adresse postale et son courriel$/ do
  @member = FactoryGirl.build(:member)
  register_new_member(@member)
end

When /^j'enregistre un membre sans son addresse$/ do
  @member = FactoryGirl.build(:member, :address => '')
  register_new_member(@member)
end

When /^j'enregistre un membre sans son nom$/ do
  @member = FactoryGirl.build(:member, :name => '')
  register_new_member(@member)
end

Alors /^un mail doit être envoyé au nouveau membre avec son nom et son mot de passe$/ do
  # TODO: trouvé un moyen de tester ça.
end

When /^j'enregistre un membre sans son courriel$/ do
  @member = FactoryGirl.build(:member, :email => '')
  register_new_member(@member)
end


When /^j'enregistre un membre avec un courriel qui existe dans la base$/ do
  @member = FactoryGirl.build(:member, :email => @board_member.email)
  register_new_member(@member)
end

When /^je remplis la date et le montant de la cotisation$/ do
  select_date 'Payé le', :with => Time.now.strftime('%Y-%m-%d')
  fill_in 'Montant', :with => '15,00'
  click_button 'Enregistrer la cotisation'
end

Lorsque /^je remplis un montant de la cotisation inférieur à (\d+) euros$/ do |amount|
  select_date 'Payé le', :with => Time.now.strftime('%Y-%m-%d')
  fill_in 'Montant', :with => (amount.to_f - 1).to_s
  click_button 'Enregistrer la cotisation'
end

Lorsque /^je remplis un montant de la cotisation égal à zéro$/ do
  fill_in 'Montant', :with => "0"
  click_button 'Enregistrer la cotisation'
end

Lorsque /^je remplis un montant de la cotisation inférieur à zéro$/ do
  fill_in 'Montant', :with => "-10"
  click_button 'Enregistrer la cotisation'
end

When /^je modifie les informations de Fabien$/ do
  @new_name = 'Fabienne'
  @new_address = 'Quelque part ailleurs'
  @new_email = 'fabienne@example.org'
  fill_in 'Nom', :with => @new_name
  fill_in 'Adresse', :with => @new_address
  fill_in 'Courriel', :with => @new_email
  click_button 'Enregistrer'
end

When /^je modifie les informations de Fabien en effaçant son adresse$/ do
  fill_in 'Adresse', :with => ''
  click_button 'Enregistrer'
end

When /^je modifie les informations de Fabien en effaçant son nom$/ do
  fill_in 'Nom', :with => ''
  click_button 'Enregistrer'
end

When /^je modifie les informations de Fabien en effaçant son courriel$/ do
  fill_in 'Courriel', :with => ''
  click_button 'Enregistrer'
end

When /^je modifie les informations de Fabien avec un courriel qui existe dans la base$/ do
  fill_in 'Courriel', :with => @board_member.email
  click_button 'Enregistrer'
end

Then /^le nouveau membre doit apparaitre dans la liste$/ do
  find('.members').should have_link(@member.name)
end

Then /^je dois voir apparaître ([^ ]*) dans la liste des membres actifs$/ do |name|
  find('.members').should have_link(name)
end

Then /^je dois voir comme date d'adhésion l'année courante$/ do
  find('.join_date').should have_content(Time.now.strftime('%Y'))
end

Then /^je dois voir comme date d'adhésion le jour, le mois et l'année de l'adhésion$/ do
  find('.join_date').should have_content(Time.now.strftime('%d/%m/%Y'))
end

Then /^je dois voir comme date de dernière cotisation l'année en cours$/ do
  @node = find('#last-subscription')
  @node.should have_content(Time.now.year.to_s)
end

Then /^je dois voir comme date de dernière cotisation (\d+)$/ do |year|
  @node = find('#last-subscription')
  @node.should have_content(year)
end

Alors /^je dois voir le montant de sa dernière cotisation$/ do
  @node = find('#last-subscription-amount')
  @node.should have_content(@member.last_subscription.amount)
end

Then /^cette date doit être de couleur verte$/ do
  @node = find('#last-subscription')
  @node[:class].split.should include('subscription-up-to-date')
end

Then /^cette date doit être de couleur rouge$/ do
  @node = find('#last-subscription')
  @node[:class].split.should include('subscription-not-renewed')
end

Then /^la date doit être de couleur rouge$/ do
  @node = find('#last-subscription')
  @node[:class].split.should include('subscription-not-renewed') 
end

Then /^je dois être redirigé vers la page du membre$/ do
  page.should have_content('Informations sur un membre')
end

Then /^je dois voir les nouvelles informations sur le membre$/ do
  page.should have_content(@new_name)
  page.should have_content(@new_address)
  page.should have_content(@new_email)
end

Given /^que je visite la page permettant de consulter les informations sur Fabien$/ do
  visit '/members/'+@fabien.id.to_s
end

Alors /^je dois voir que le courriel « (.*) » car il est déjà utilisé$/ do |message|
  find('#main').should have_content(message)
end

Lorsque /^que je génère la liste des adresses électroniques$/ do
  visit members_list_path
end

Alors /^je dois voir l'adresse électronique de Fabien$/ do
  page.should have_content(@fabien.email)
end

Alors /^je ne dois pas voir l'adresse électronique du membre$/ do
  page.should_not have_content(@member.email)
end

# Pour le bogue #400
Alors /^je dois voir le jour, le mois et l'année de la cotisation$/ do
  page.should have_content(@member.subscriptions.all.last.paid_on.strftime("%d/%m/%Y"))
end

Alors /^je dois voir des liens vers les pages de documentation des services$/ do
  @node = find('.liens.documentation')
  @node.should have_link('Tunnels chiffrés (VPN)', :href => 'http://www.rezine.org/documentation/tunnels_chiffres/')
  @node.should have_link('Mise en place d\'une Brique Internet', :href => 'http://www.rezine.org/documentation/brique/')
end

Alors /^je dois voir un lien vers le support de Rézine$/ do
  @node = find('.liens.support')
  @node.should have_link('support@rezine.org', :href => 'mailto:support@rezine.org')
end

