# -*- coding: utf-8 -*-

Given /^que la plage IP dédiée au réseau VPN est "(.*?)"$/ do |netmask|
  @network = FactoryGirl.create(:network, :netmask_ipv4 => netmask)
end

Given /^que Fabien possède un abonnement VPN$/ do
  @network = FactoryGirl.create(:network)
  @vpn_service_fabien = FactoryGirl.create(:vpn_service, :member => @fabien)
end

Etantdonné /^que je visite la page des détails techniques de l'abonnement VPN de Fabien$/ do
  visit '/vpn_services/' + @vpn_service_fabien.id.to_s
end

Etantdonné /^que je visite la page de modification des détails techniques de l'abonnement VPN de Fabien$/ do
  visit '/vpn_services/' + @vpn_service_fabien.id.to_s + '/edit'
end

Etantdonné /^que je visite la page de liste des abonnements$/ do
  visit '/vpn_services'
end

Lorsque /^je visite la page de liste des abonnements$/ do
  visit '/vpn_services'
end

Given /^que je visite la page d'enregistrement d'un nouvel abonnement VPN$/ do
  visit '/vpn_services/new'
end

Lorsque /^j'enregistre un abonnement VPN pour Fabien pour (\d+) mois$/ do |month|
  select(month + ' mois', :from => "Date d'expiration")
  select(@fabien.name, :from => "Membre")
  click_button "Enregistrer l'abonnement VPN"
end

Alors /^le nouveau compte VPN doit apparaitre dans la liste des abonnements$/ do
  page.should have_content('Liste des abonnements')
  find("table#t_list_vpn tr td.t_vpn_id").visible?.should be_true
end

Alors /^la date d'expiration de l'abonnement doit être dans (\d+) mois$/ do |month|
  find("table#t_list_vpn tr td.t_vpn_expired_at").should have_content((Date.today + month.to_i.month).to_s)
end

Alors /^un mot de passe doit avoir été généré$/ do
  VpnService.first.password.empty?.should be_false
end

Alors /^une adresse IPv4 "(.*?)" doit avoir été affectée automatiquement en fonction de la disponibilité dans la plage dédiée au VPN$/ do |ipv4|
  VpnService.first.ipv4.should == ipv4
end

Alors /^je dois voir apparaitre la liste des abonnements$/ do
  page.should have_content('Liste des abonnements')
  find("table#t_list_vpn tr td.t_vpn_id").visible?.should be_true
end

Alors /^je dois voir affichée la liste des abonnements du membre$/ do
  page.should have_content('Liste des abonnements')
  find("table#t_list_vpn tr td.t_vpn_id").visible?.should be_true
end

Etantdonné /^que Fabien possède un abonnement VPN expirant dans (\d+) mois$/ do |month|
  @network = FactoryGirl.create(:network)
  @vpn_service2_fabien = FactoryGirl.create(:vpn_service, :member => @fabien, :ipv4 => nil, :expired_at => Date.today + month.to_i.month)
end

Alors /^je dois voir apparaitre que la date d'expiration de l'abonnement est dans (\d+) mois$/ do |month|
   find("table#t_list_vpn tr td.t_vpn_expired_at").should have_content((Date.today + month.to_i.month).to_s)
end

Alors /^je dois voir apparaitre que Fabien est titulaire d'un abonnement de type VPN$/ do
  find("table#t_list_vpn tr td.t_type").should have_content("VPN")
end

Alors /^je dois voir le login de cet abonnement VPN$/ do
  find("p.t_vpn_login").should have_content(@vpn_service_fabien.login)
end

Alors /^je dois voir apparaitre l'IPv(\d+) alloués à cet abonnement VPN$/ do |arg1|
  find("p.t_vpn_ipv4").should have_content(@vpn_service_fabien.ipv4)
end

Alors /^je dois voir apparaitre le mot de passe du VPN$/ do
  find("p.t_vpn_password").should have_content(@vpn_service_fabien.password)
end

Alors /^je dois voir le login de mon abonnement VPN$/ do
  find("p.t_vpn_login").should have_content(@vpn_service_member.login)
end
Alors /^je dois voir apparaitre l'IPv(\d+) alloués à mon abonnement VPN$/ do |arg1|
  find("p.t_vpn_ipv4").should have_content(@vpn_service_member.ipv4)
end

Alors /^je dois voir apparaitre le mot de passe de mon VPN$/ do
  find("p.t_vpn_password").should have_content(@vpn_service_member.password)
end

Alors /^je dois voir le type de chaque abonnement$/ do
  find("table#t_list_vpn tr td.t_type").should have_content("VPN")
end

Alors /^je dois voir la date d'expiration de l'abonnement$/ do
  find("table#t_list_vpn tr td.t_vpn_expired_at").should have_content(@vpn_service_fabien.expired_at.strftime("%F"))
end

Alors /^je dois voir un lien vers les détails techniques de chaque abonnement$/ do
  find('table#t_list_vpn').should have_link('Détails techniques')
end

Alors /^je dois voir un lien vers la modification de chaque abonnement$/ do
  find('table#t_list_vpn').should have_link('Modifier l\'abonnement')
end

Alors /^je dois voir un lien vers la suppression de chaque abonnement$/ do
  find('table#t_list_vpn').should have_link('Supprimer l\'abonnement')
end

Lorsque /^je souhaite ajouter un abonnement au membre$/ do
  click_link 'Ajouter un nouvel abonnement VPN'
end

Alors /^je suis redirigé vers la page d'enregistrement d'un nouvel abonnement$/ do
  page.should have_content('Nouvel abonnement')
end

Alors /^le champ du membre est pré\-rempli$/ do
  page.should have_select("Membre", :selected_value => @fabien.name)
end

Given /^que je possède au moins un abonnement$/ do
  @network = FactoryGirl.create(:network)
  @vpn_service_member = FactoryGirl.create(:vpn_service, :member => @member)
end

Given /^que je possède un abonnement VPN$/ do
  @network = FactoryGirl.create(:network)
  @vpn_service_member = FactoryGirl.create(:vpn_service, :member => @member)
end

Alors /^je dois voir les différents abonnements auxquels j'ai souscrits$/ do
  page.should have_content('Liste des abonnements')
  find("table#t_list_vpn tr td.t_vpn_id").visible?.should be_true
end

Alors /^je dois voir le nombre total de services VPN actifs$/ do
  @nodevpn = find('.vpn_service_count')
  @nodevpn.should have_content(VpnService.count)
end

Etantdonné /^que je visite la page des détails techniques d'un de mes abonnements de type VPN$/ do
  visit '/vpn_services/' + @vpn_service_member.id.to_s
end

When /^je dois pouvoir changer le login de cet abonnement VPN$/ do
  @new_login = 'new_vpn'
  fill_in 'vpn_service_login', :with => @new_login
end

When /^je dois voir le bouton « Générer un nouveau mot de passe » pour cet abonnement VPN$/ do
  find_button('Générer un nouveau mot de passe').click
end

When /^je dois pouvoir ajouter (\d+) mois à la date d'expiration de cet abonnement VPN$/ do |month|
  @new_expirate_at = Date.today + month.to_i.month
  select(month + ' mois', :from => 'vpn_service_expired_at')
end

# bogue #435
Etantdonné /^que je visite la page de modification des détails techniques d'un de mes abonnements de type VPN$/ do
  visit '/vpn_services/' + @vpn_service_member.id.to_s + '/edit'
end

Alors /^je dois voir un message d'erreur « (.*) »$/ do |message|
  find('#flash_alert').should have_content(message)
end

Etantdonné /^que je reviens en arriere$/ do
  click_link "Back"
end

Lorsque /^je modifie un ou plusieurs détails techniques d'un abonnement VPN de Fabien$/ do
  visit '/vpn_services/' + @vpn_service_fabien.id.to_s + '/edit'
  @new_login = 'vpn69'
  @new_expired_at = Date.today + 6.months
  fill_in 'vpn_service_login', :with => @new_login
  select( @new_expired_at.to_s, :from => 'vpn_service_expired_at')
  click_button "Modifier ce(tte) Vpn service"
end

Alors /^je dois être redirigé vers la page de l'abonnement VPN de Fabien$/ do
  page.should have_content('Membre: ' + @fabien.name)
end

Alors /^je dois voir les nouveaux détails techniques de l'abonnement VPN$/ do
  page.should have_content('Login: vpn69')
end

# TODO
Lorsque /^je modifie la date d'expiration d'un abonnement VPN de Fabien en utilisant une date dans le passé$/ do
  visit '/vpn_services/' + @vpn_service_fabien.id.to_s + '/edit'
  @new_expired_at = Date.today - 6.months
  select( @new_expired_at.to_s, :from => 'vpn_service_expired_at')
end
