require 'spec_helper'

describe DashboardController do
  describe "GET 'index'" do
    before(:each) do
      @member = FactoryGirl.create(:member)
    end

    context 'when not logged in' do
      it 'should redirect me to the login page' do
        get :index
        response.should redirect_to(new_member_session_path)
      end
    end

    context 'when logged in as a simple member' do
      before(:each) do
        sign_in @member
      end

      it "should be successful" do
        get :index
        response.should be_success
      end

      it "should look me up" do
        get :index
        assigns(:member).should == @member
      end
    end

    context 'when logged in as a board member' do
      before(:each) do
        @board_member = FactoryGirl.create(:board_member)
        sign_in @board_member
      end

      it "should be successful" do
        get :index
        response.should be_success
      end

      it "should look me up" do
        get :index
        assigns(:member).should == @board_member
      end

      it "should look up the current member count" do
        get :index
        assigns(:member_count).should == Member.all.count
      end
    end
  end
end
