require 'spec_helper'

describe SubscriptionsController do
  describe "POST 'create'" do
    let(:member) { FactoryGirl.create(:member) }
    let(:paid_on) { Time.now }
    let(:amount) { '15,00' }

    def post_create
      post :create, :member_id => member.id, :paid_on => paid_on, :amount => amount
    end

    let(:subscription) { mock_model(Subscription).as_null_object }

    before(:each) do
      Subscription.stub(:new).and_return(subscription)
    end

    context 'when not logged in' do
      it 'should redirect me to the login page' do
        post_create
        response.should redirect_to(new_member_session_path)
      end
    end

    context 'when logged in as a simple member' do
      before(:each) do
        sign_in member
      end

      it 'should deny me access' do
        expect {
          post_create
        }.to raise_error(CanCan::AccessDenied)
      end
    end

    context 'when logged in as a board member' do
      before(:each) do
        @board_member = FactoryGirl.create(:board_member)
        sign_in @board_member
      end

      it 'creates a new subscription' do
        Subscription.should_receive(:new).
            with(:member => member, :paid_on => paid_on, :amount => '15,00')
        post_create
      end

      it 'saves the subscription' do
        subscription.should_receive(:save)
        post_create
      end

      it 'redirects to the member page' do
        post_create
        response.should redirect_to(member)
      end
    end
  end
end
