require 'spec_helper'

describe VpnServicesController do

  describe "GET 'index'" do
    before(:each) do
      @member = FactoryGirl.create(:member)
      @network = FactoryGirl.create(:network)
      @member_fabien = FactoryGirl.create(:fabien)
      @vpn_member = FactoryGirl.create(:vpn_service, :member => @member)
      @vpn_fabien = FactoryGirl.create(:vpn_service, :member => @member_fabien, :ipv4 => '10.255.6.67')
    end

    context 'when not logged in' do
      it 'should redirect me to the login page' do
        get :index
        response.should redirect_to(new_member_session_path)
      end
    end

    context 'when logged in as a simple member' do
      before(:each) do
        sign_in @member
      end

      it 'should not show vpn of other members' do
        get :index
        assigns(:vpn_services).should == [@vpn_member]
      end
    end

    context 'when logged in as a board member' do
      before(:each) do
        @board_member = FactoryGirl.create(:board_member)
        sign_in @board_member
      end

      it "should be successful" do
        get :index
        response.should be_success
      end

      it 'should show all vpn' do
        get :index
        assigns(:vpn_services).should == VpnService.all
      end
    end
  end

  describe "GET 'show'" do
    before(:each) do
      @member = FactoryGirl.create(:member)
      @network = FactoryGirl.create(:network)
      @member_fabien = FactoryGirl.create(:fabien)
      @vpn_member = FactoryGirl.create(:vpn_service, :member => @member)
      @vpn_fabien = FactoryGirl.create(:vpn_service, :member => @member_fabien, :ipv4 => '10.255.6.67')
    end

    context 'when not logged in' do
      it 'should redirect me to the login page' do
        get :show, :id => @member.id
        response.should redirect_to(new_member_session_path)
      end
    end

    context 'when logged in as a simple member' do
      before(:each) do
        sign_in @member
      end

      it 'should deny me access' do
        expect {
          get :show, :id => @vpn_fabien.id
        }.to raise_error(CanCan::AccessDenied)
      end
      
      it "should be successful" do
        get :show, :id => @vpn_member.id
        response.should be_success
      end
      
    end

  end

  describe "POST create" do
    let(:member) { FactoryGirl.create(:member) }

    def post_create
      post :create, :vpn_service => { :member_id => member.id }
    end

    let(:vpn_service) { mock_model(VpnService).as_null_object }

    before(:each) do
      VpnService.stub(:new).and_return(vpn_service)
    end

    context 'when not logged in' do
      it 'should redirect me to the login page' do
        post_create
        response.should redirect_to(new_member_session_path)
      end
    end

    context 'when logged in as a simple member' do
      before(:each) do
        sign_in member
      end

      it 'should deny me access' do
        expect {
          post_create
        }.to raise_error(CanCan::AccessDenied)
      end
    end

    context 'when logged in as a board member' do
      before(:each) do
        @board_member = FactoryGirl.create(:board_member)
        sign_in @board_member
      end

      it 'creates a new vpn_service' do
        pending "change vpn service route so that services belong to members" do
          VpnService.should_receive(:new).
              with(:member => member)
          post_create
        end
      end

      it 'saves the vpn_service' do
        vpn_service.should_receive(:save)
        post_create
      end

      it 'redirects to the member page' do
        post_create
        response.should redirect_to(vpn_service)
      end
    end
 end

end
