# -*- coding: utf-8 -*-

require 'spec_helper'
require 'time'

describe Subscription do
  it 'should create a new instance given valid attributes' do
    FactoryGirl.build(:subscription)
  end

  it 'should require a member' do
    no_member_sub = FactoryGirl.build(:subscription, :member => nil)
    no_member_sub.should_not be_valid
  end

  it 'should have a payment date' do
    no_year_sub = FactoryGirl.build(:subscription, :paid_on => nil)
    no_year_sub.should_not be_valid
  end

  it 'should allow to set amounts in euro' do
    sub = FactoryGirl.build(:subscription, :amount => '€15,00')
    sub.amount_cents.should == 1500
  end

  it 'should not allow to set amounts inferior to 15 euros' do
    sub = FactoryGirl.build(:subscription, :amount => '€10,00')
    sub.should_not be_valid
  end

  it 'should not allow to set amounts of 0 euros' do
    sub = FactoryGirl.build(:subscription, :amount => '€0,00')
    sub.should_not be_valid
  end

  it 'should not allow to set negative amounts' do
    sub = FactoryGirl.build(:subscription, :amount => '€-10,00')
    sub.should_not be_valid
  end

  describe "subscription payment date" do
    before(:each) do
      @subscription = FactoryGirl.create(:subscription)
    end

    it "should be a kind of time" do
      @subscription.paid_on.should be_kind_of(Time)
    end
  end

end
