require 'spec_helper'

describe VpnService do
  
  before(:each) do
    @network = FactoryGirl.create(:network)
  end
    
  it 'should create a new instance given valid attributes' do
    FactoryGirl.build(:vpn_service)
  end

  it 'should require a member' do
    no_member_sub = FactoryGirl.build(:vpn_service, :member => nil)
    no_member_sub.should_not be_valid
  end
  
  it 'should require a expiration date' do
    no_expiration_date_sub = FactoryGirl.build(:vpn_service, :expired_at => nil)
    no_expiration_date_sub.should_not be_valid
  end

  it 'should require an expiration date after current date' do
    expiration_date_before_sub = FactoryGirl.build(:vpn_service, :expired_at => Date.yesterday)
    expiration_date_before_sub.should_not be_valid
  end

  it 'should require an expiration date not egal to current date' do
    expiration_date_same_current_sub = FactoryGirl.build(:vpn_service, :expired_at => Date.current)
    expiration_date_same_current_sub.should_not be_valid
  end
  
  it 'should default require a 16 caracters password' do
    sub_week_password = FactoryGirl.build(:vpn_service, :password => 'txra2ophd67huec')
    sub_week_password.should_not be_valid
  end
  
  it 'should default require a valid ipv4 address' do
    ipaddress_invalid_sub = FactoryGirl.build(:vpn_service, :ipv4 => 'invalid')
    ipaddress_invalid_sub.should_not be_valid
    @fabien = FactoryGirl.create(:fabien)
    ipaddress_valid_sub = FactoryGirl.build(:vpn_service, :ipv4 => '10.255.6.64', :member => @fabien)
    ipaddress_valid_sub.should be_valid
  end
  
  it 'should default select the second free ipv4 address in the vpn network range' do
    FactoryGirl.create(:vpn_service)
    @fabien = FactoryGirl.create(:fabien)
    vpn_service = FactoryGirl.create(:vpn_service, :ipv4 => nil, :member => @fabien)
    vpn_service.ipv4.should == '10.255.6.67'
  end
  
  it 'should require a ipv4 address under the right network ip range' do
    ipaddress_not_in_range_sub = FactoryGirl.build(:vpn_service, :ipv4 => '10.255.4.18')
    ipaddress_not_in_range_sub.should_not be_valid
  end

  it 'should require a ipv4 address not first or last in the network ip range' do
    ipaddress_not_in_range_sub = FactoryGirl.build(:vpn_service, :ipv4 => '10.255.6.65')
    ipaddress_not_in_range_sub.should_not be_valid
  end
  
  it 'should require a ipv4 address not already used' do
    FactoryGirl.create(:vpn_service)
    @fabien = FactoryGirl.create(:fabien)
    vpn_service = FactoryGirl.build(:vpn_service, :ipv4 => '10.255.6.66', :member => @fabien)
    vpn_service.should_not be_valid
  end
  
  it 'should default generate a valid login (format: vpnID)' do
    FactoryGirl.build(:vpn_service)
    @fabien = FactoryGirl.create(:fabien)
    vpn_service = FactoryGirl.create(:vpn_service, :member => @fabien)
    vpn_service.login.should == 'vpn1'
  end
  
  it 'should require a valid login on update (format: vpnID)' do
    @fabien = FactoryGirl.create(:fabien)
    vpn_service = FactoryGirl.create(:vpn_service, :member => @fabien)
    vpn_service.login = 'vpnaaaa'
    vpn_service.should_not be_valid
  end
  
  it 'should override invalid login on create (format: vpnID)' do
    @fabien = FactoryGirl.create(:fabien)
    vpn_service = FactoryGirl.create(:vpn_service, :member => @fabien, :login => 'vpn56')
    vpn_service.login.should == 'vpn1'
  end

end
